from math import sqrt, acos, pi


class Triangle:
    """Class corresponds for triangles and calculates its params"""

    def __init__(self, x1, y1, x2, y2, x3, y3, index=None):
        self.index = index
        # Find sides via coordinates
        side_1 = sqrt(abs(x3 - x1) ** 2 + abs(y3 - y1) ** 2)
        side_2 = sqrt(abs(x2 - x1) ** 2 + abs(y2 - y1) ** 2)
        side_3 = sqrt(abs(x3 - x2) ** 2 + abs(y3 - y2) ** 2)
        self.sides = [side_1, side_2, side_3]

        # Find angles via Cosine Theorem
        angle_1 = 180 * acos((side_1 ** 2 + side_3 ** 2 - side_2 ** 2) / (2 * side_1 * side_3)) / pi
        angle_2 = 180 * acos((side_1 ** 2 + side_2 ** 2 - side_3 ** 2) / (2 * side_1 * side_2)) / pi
        angle_3 = 180 * acos((side_2 ** 2 + side_3 ** 2 - side_1 ** 2) / (2 * side_2 * side_3)) / pi
        self.angles = [angle_1, angle_2, angle_3]

        # Store neighbour angles of each side
        self.sides2angles = {
            side_1: [angle_1, angle_2],
            side_2: [angle_2, angle_3],
            side_3: [angle_1, angle_3]
        }

        self.opposite_angles = {
            side_1: angle_3,
            side_2: angle_1,
            side_3: angle_2
        }

    def __str__(self):
        """Return stringified class"""
        return f"Triangle_{self.index}(\n\tsides={self.sides},\n\tangles={self.angles},\n\tsides2angles={self.sides2angles}\n)"


t = int(input())
n = int(input())
triangles = []
# Create instances
for triangle_i in range(n):
    params = list(map(int, input().split()))
    triangles.append(Triangle(*params, index=triangle_i + 1))

possible = []

# Iterate over all triangles and for each one find eligible neighbours
for triangle_1 in triangles:
    for triangle_2 in triangles:
        for triangle_3 in triangles:
            for triangle_4 in triangles:
                if triangle_1 == triangle_2 or \
                        triangle_1 == triangle_4 or \
                        triangle_1 == triangle_3 or \
                        triangle_2 == triangle_3 or \
                        triangle_2 == triangle_4 or \
                        triangle_3 == triangle_4:
                    continue

                # Check for sides match

                eligible = True

                for side in triangle_1.sides:
                    if side not in triangle_2.sides and \
                            side not in triangle_3.sides and \
                            side not in triangle_4.sides:
                        eligible = False
                        break

                if not eligible:
                    continue

                eligible = False

                for angle_2 in triangle_2.angles:
                    for angle_3 in triangle_3.angles:
                        for angle_4 in triangle_4.angles:
                            if angle_2 + angle_3 + angle_4 == 180:
                                eligible = True
                                break

                        if eligible:
                            break

                    if eligible:
                        break

                if not eligible:
                    continue

                # Find possible neighbours for each inner side

                matches = {}

                for side in triangle_1.sides:
                    for inner_triangle in [triangle_2, triangle_3, triangle_4]:
                        if side in inner_triangle.sides and inner_triangle not in matches.values():
                            matches[side] = inner_triangle
                            break

                overall = 0

                for side, match in matches.items():
                    # print(side, match)
                    overall += match.opposite_angles[side]

                # print(overall)

                if round(overall) != 180:
                    continue

                # print(f"{triangle_1}\n{triangle_2}\n{triangle_3}\n{triangle_4}\n\n=====================\n\n")

                match = [triangle_1.index, triangle_2.index, triangle_3.index, triangle_4.index]
                match.sort()
                match = ' '.join(list(map(str, match)))
                if match not in possible:
                    possible += [match]

print(len(possible))
print('\n'.join(list(map(str, possible))))
